package Net::Server::Fork;

use strict;
use vars qw($VERSION @ISA);
use Net::Server;


$VERSION = 0.3;

### fall back to parent methods
@ISA = qw(Net::Server);


### make sure some defaults are set
sub post_configure {
  my $self = shift;

  ### let the parent do the rest
  $self->SUPER::post_configure;

  ### how often to see if children are alive
  $self->{check_for_dead} = 30
    unless defined $self->{check_for_dead};

  ### I need to know who is the parent
  $self->{ppid} = $$;

}


### prepare for connections
sub loop {
  my $self = shift;

  ### get ready for children
  $SIG{CHLD} = 'IGNORE';
  $self->{children} = {};

  my $last_checked_for_dead = time;

  ### this is the main loop
  while( $self->accept ){

    my $pid = fork;
      
    ### trouble
    if( not defined $pid ){
      $self->log(1,"Bad fork [$!]");
      sleep(5);
        
    ### parent
    }elsif( $pid ){

      close($self->{client});
      $self->{children}->{$pid} = time;
        
    ### child
    }else{

      $self->run_client_connection;
      exit;

    }

    my $time = time;

    ### periodically see which children are alive
    if( $time - $last_checked_for_dead > $self->{check_for_dead} ){
      $last_checked_for_dead = $time;
      foreach (keys %{ $self->{children} }){
        ### see if the child can be killed
        kill(0,$_) or delete $self->{children}->{$_};
      }
    }

  }
}


1;
