package Net::Server::MultiType;

use strict;
use vars qw($VERSION @ISA);
use Net::Server;


$VERSION = 0.3;

### fall back to parent methods
### we will start out with this, but it should be different if overriden
@ISA = qw(Net::Server);

### allow for override-able options
sub options {
  my $self = shift;
  my $ref  = shift;

  $self->SUPER::options($ref);

  foreach ( qw(server_type) ){
    $self->{$_} = [] unless exists $self->{$_};
    $ref->{$_} = $self->{$_};
  }
}


sub run {

  ### build our own object
  ### this is assuming that new isn't overriden in other packages
  my $class = shift;
  my $self  = bless {}, $class;


  ### do the configuration now
  $self->configure(@_);

  ### don't do anything if I haven't specified a type
  if( defined $self->{server_type} ){

    ### make sure server_type is an array ref
    $self->{server_type} = [$self->{server_type}]
      unless ref $self->{server_type};

    ### iterate on the passed types
    foreach (@{ $self->{server_type} }){

      next if $_ eq 'MultiType';
      next if ! /^(\w+)$/;
      $_ = $1; # satisfy taint

      my $package = "Net::Server::$_";
      my $package_file = $package .'.pm';
      $package_file =~ s{::}{/}g;
      
      ### see if the package is available
      eval { require $package_file; };

      ### skip if there was an error
      if( $@ ){
        print STDERR "Couldn't become server type \"$package\" [$@]\n";
        next;
      }

      ### turn me into that package
      require $package_file; # outside the eval block
      unshift @ISA, $package;
      warn("Becoming sub class of \"$package\"\n");

      ### success - skip any others
      last;
      
    }

  }

  ### now run as the new type of thingy
  ### passing self, instead of package, doesn't instantiate a new object
  $self->SUPER::run();

}

1;
